summaryrefslogtreecommitdiffstats
path: root/kpresenter/KPrCanvas.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpresenter/KPrCanvas.h')
-rw-r--r--kpresenter/KPrCanvas.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kpresenter/KPrCanvas.h b/kpresenter/KPrCanvas.h
index e2b373e1..f5355be7 100644
--- a/kpresenter/KPrCanvas.h
+++ b/kpresenter/KPrCanvas.h
@@ -376,8 +376,8 @@ exportPage( 0, s, 800, 600, "/home/khz/page0.png", "PNG", 100 );
void objectPopup( KPrObject *object, const TQPoint &point );
public slots:
- // use tqrepaint = false when the KPrCanvas is destroyed to avaid a possible crash
- void exitEditMode( bool tqrepaint = true );
+ // use repaint = false when the KPrCanvas is destroyed to avaid a possible crash
+ void exitEditMode( bool repaint = true );
void clipCut();
void clipCopy();
@@ -543,9 +543,9 @@ protected:
TQRect getPageRect( bool decBorders = true ) const;
unsigned int pageNums() const;
- void _tqrepaint( bool erase=true );
- void _tqrepaint( const TQRect &r );
- void _tqrepaint( KPrObject *o );
+ void _repaint( bool erase=true );
+ void _repaint( const TQRect &r );
+ void _repaint( KPrObject *o );
/**
* Draw page defined in step to painter.
@@ -692,7 +692,7 @@ private:
* @param pos the point which should be snapped
* @param repaintSnapping true if the guides should be repainted.
* @param repaintSnapping false when the guides should not be repainted.
* You have to call tqrepaint by yourself.
*
* @return the position of the snapped point
*/
@@ -692,7 +692,7 @@ private:
* @param repaintSnapping true if the guides should be repainted.
* @param repaintSnapping false when the guides should not be repainted.
- * You have to call tqrepaint by yourself.
+ * You have to call repaint by yourself.
*
* @return the position of the snapped point